#
# spec file for package perl-Config-IniFiles
#
# Copyright (c) 2020 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           perl-Config-IniFiles
Version:        3.000003
Release:        1.15
%define cpan_name Config-IniFiles
Summary:        Module for reading .ini-style configuration files
License:        Artistic-1.0 OR GPL-1.0-or-later
Group:          Development/Libraries/Perl
Url:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/S/SH/SHLOMIF/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(IO::Scalar)
BuildRequires:  perl(List::Util) >= 1.33
BuildRequires:  perl(Module::Build) >= 0.280000
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(parent)
Requires:       perl(IO::Scalar)
Requires:       perl(List::Util) >= 1.33
%{perl_requires}

%description
Config::IniFiles provides a way to have readable configuration files
outside your Perl script. Configurations can be imported (inherited,
stacked,...), sections can be grouped, and settings can be accessed from a
tied hash.

%prep
%setup -q -n %{cpan_name}-%{version}

%build
perl Build.PL installdirs=vendor
./Build build flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install destdir=%{buildroot} create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%defattr(-,root,root,755)
%doc Changes OLD-Changes.txt README
%license LICENSE

%changelog
* Wed Mar 25 2020 <timueller+perl@suse.de>
- updated to 3.000003
  see /usr/share/doc/packages/perl-Config-IniFiles/Changes
* Fri Mar 15 2019 Stephan Kulow <coolo@suse.com>
- updated to 3.000002
  see /usr/share/doc/packages/perl-Config-IniFiles/Changes
* Thu Jan 17 2019 Stephan Kulow <coolo@suse.com>
- updated to 3.000001
  see /usr/share/doc/packages/perl-Config-IniFiles/Changes
* Wed Sep 19 2018 Stephan Kulow <coolo@suse.com>
- updated to 3.000000
  see /usr/share/doc/packages/perl-Config-IniFiles/Changes
* Sun Apr 22 2018 coolo@suse.com
- updated to 2.98
  see /usr/share/doc/packages/perl-Config-IniFiles/Changes
* Sun Apr  8 2018 coolo@suse.com
- updated to 2.96
  see /usr/share/doc/packages/perl-Config-IniFiles/Changes
* Sat Mar 17 2018 coolo@suse.com
- updated to 2.95
  see /usr/share/doc/packages/perl-Config-IniFiles/Changes
  * Make use of perltidy and test for it.
  * Remove firstload / reload logic
  - https://rt.cpan.org/Ticket/Display.html?id=104763
  - thanks to José Joaquín Atria
* Wed Nov 30 2016 coolo@suse.com
- updated to 2.94
  see /usr/share/doc/packages/perl-Config-IniFiles/Changes
* Mon Jul 25 2016 coolo@suse.com
- updated to 2.93
  see /usr/share/doc/packages/perl-Config-IniFiles/Changes
* Thu Jun 23 2016 coolo@suse.com
- updated to 2.92
  see /usr/share/doc/packages/perl-Config-IniFiles/Changes
* Sun Jun 12 2016 coolo@suse.com
- updated to 2.91
  see /usr/share/doc/packages/perl-Config-IniFiles/Changes
* Thu May  5 2016 coolo@suse.com
- updated to 2.89
  see /usr/share/doc/packages/perl-Config-IniFiles/Changes
* Sun Jul 12 2015 coolo@suse.com
- updated to 2.88
  see /usr/share/doc/packages/perl-Config-IniFiles/Changes
* Thu Jun 18 2015 coolo@suse.com
- updated to 2.87
  see /usr/share/doc/packages/perl-Config-IniFiles/Changes
* Thu Apr 16 2015 coolo@suse.com
- updated to 2.86
  see /usr/share/doc/packages/perl-Config-IniFiles/Changes
* Sun Feb  9 2014 coolo@suse.com
- updated to 2.83
  * Add a LICENSE file and section.
  - Kwalitee.
  * Minimum version is now perl-5.8.0.
  - CPANTS Kwalitee.
* Mon Jun  3 2013 coolo@suse.com
- updated to 2.82
  * Add t/style-trailing-space.t .
  - Remove trailing space.
  * Add the CopySection method to copy a section.
  - Thanks to James Rouzier.
  * Add the RenameSection method to rename a section.
  - Thanks to James Rouzier.
  * Fix test failures with Pod-Simple-3.28:
  - http://www.cpantesters.org/cpan/report/98f9d3a8-b557-11e2-9adc-3d5fc1508286
  * Fix https://rt.cpan.org/Public/Bug/Display.html?id=80259:
  - Warnings on undefined value in length in perl-5.10.x.
  * Bump the List::MoreUtils dependency to '0.33'.
  - https://rt.cpan.org/Ticket/Display.html?id=77930
  - Thanks to TJENNESS for the report.
  * Correct the documentation regarding the syntax of calling ->WriteConfig(),
  which always accepts a mandatory filename and not just
  "->WriteConfig(-delta => 1)".
  - Thanks to the Mageia Linux QA team at:
  - https://bugs.mageia.org/show_bug.cgi?id=6024#c17
* Wed May 30 2012 vcizek@suse.com
- update to 2.75
- fixes CVE-2012-2451 (bnc#760459)
  * SECURITY BUG FIX: Config::IniFiles used to write to a temporary filename
  with a predictable name ("${filename}-new") which opens the door for potential
  exploits.
  * Now requiring Fcntl (which is a core module) for SEEK_SET() and SEEK_CUR().
  * Now requiring List::MoreUtils (for any() and other functions), File::Temp
  and File::Basename .
  * Fix the test dependency (in the new t/31comments_with_spaces.t test)
  on IO::stringy (now writing it to a file).
  - This caused some CPAN Testers failures such as:
  - http://www.cpantesters.org/cpan/report/c16b9978-7f40-11e1-9d6f-f6dbfa7543f5
  * Modernized some of the open() calls in the test files.
  - three args open, lexcial file handles, etc.
  * Fix https://sourceforge.net/tracker/?func=detail&aid=3388382&group_id=6926&atid=106926
  - "Trailing comments with whitespace are not recognised"
  - Thanks to briconaut for the report and to rbowen for the patch and test.
  * Add the method ->OutputConfigToFileHandle which is a more explicit and
  safer version of ->OutputConfig.
  - ->OutputConfig now uses it.
  - all existing tests pass, and a new test was added to
    t/15store-and-retrieve-here-doc-terminator.t .
* Wed Dec  7 2011 coolo@suse.com
- fix license to be in spdx.org format
* Thu Jun 23 2011 vcizek@novell.com
- update to 2.68
  * Typo correction: https://rt.cpan.org/Ticket/Display.html?id=69003
  Version 2.67:    ( Tue Jun 21 14:55:07 IDT 2011 )
  * Made sure that parameters with empty values will be written to the file.
  - Fixes https://rt.cpan.org/Public/Bug/Display.html?id=68554 .
* Mon Jan 31 2011 vcizek@novell.com
- update to 2.66
  * Add support for the handle_trailing_comment option to support trailing
  comments at the end of a param=value line.
  - Fixes https://rt.cpan.org/Public/Bug/Display.html?id=43843 .
  - Original patch by Peter Xu.
  - Some comments and corrections of the patch by Shlomi Fish (the current
    Config-IniFiles maintainer.)
* Fri Dec 10 2010 coolo@novell.com
- fix spec file
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Wed Dec  1 2010 anicka@suse.cz
- update to 2.65
  * Replaced calls to File::Temp's tempfile() with those to its tempdir()
  followed by File::Spec->catfile() - hopefully fixes the CPAN smoking failures
  on Win32.
* Mon Nov 22 2010 anicka@suse.cz
- update to 2.64
  * bugfixes
  * Add -nomultiline option.
  * Add the tag-release.pl file to tag a release.
* Sun Jul 25 2010 chris@computersalat.de
- removed dos2unix usage
* Wed Jun  2 2010 chris@computersalat.de
- update to 2.58
  * Incorporated a fix for some broken POD.
  - https://rt.cpan.org/Ticket/Display.html?id=51617
  - Thanks to Frank Wiegand for reporting it.
  * Got rid of \r/carriage-returns's in lib/Config/IniFiles.pm .
  - It interfered with applying a patch.
  * Applied a patch to get rid of indirect object notation in the documentation
    and code ("new Config::IniFiles") and replace it with Config::IniFiles->new().
  - https://rt.cpan.org/Ticket/Display.html?id=57536
  - Thanks to Tom Molesworth for the patch.
- package recreated by cpanspec 1.78
- noarch package
- switch from Makefile.PL > Build.PL
* Thu Mar  4 2010 anicka@suse.cz
- update to 2.57
  * Fixed failure to read the ini file contents from a filehandle made out of a
  scalar
  - https://rt.cpan.org/Ticket/Display.html?id=45997
  - Applied a patch by Nicolas Mendoza - thanks!
* Wed Jan 13 2010 anicka@suse.cz
- update to 2.56
  * Hopefully fixed the skip() in t/07misc.t
  - https://rt.cpan.org/Public/Bug/Display.html?id=53238
  - It was skip($num, $label) instead of skip($label, $num) and it
    lacked a "SKIP:" label.
  * Refactoring the tests:
  - Converted t/05hash.t to Test::More and modernised it.
  - Converted t/06oo.t to Test::More and modernised it.
  - Testing: extracted t/lib/Config/IniFiles/TestPaths.pm.
  - Converted t/10delta.t to Test::More and modernised it.
  - Add the t_unlink method.
  * Adapted t/25line-endings.t to perl-5.6.x .
  - http://www.nntp.perl.org/group/perl.cpan.testers/2009/11/msg6026936.html
  - Failure there.
  * Converted t/01basic.t to Test::More and modernised it.
  * Converted t/02weird.t to Test::More and modernised it.
  * Converted t/04import.t to Test::More and modernised it.
  * Applied a patch from Steffen Heinrich (SHE) for:
  - https://rt.cpan.org/Ticket/Display.html?id=51445
  - included t/25line-endings.t
  - modified a little.
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Mon Aug  3 2009 anicka@suse.cz
- update to 2.52
  * Added more keys to Build.PL (author, etc.)
  * Added resources and keywords to META.yml.
  * Converted t/00load.t to Test-More.
  * No longer chdir()-ing into "t" in t/00load.t
  * Got rid of the "new Config::IniFiles" syntax in the tests.
  - replaced with Config::IniFiles->new().
  - see "Perl Best Practices", "Programming Perl", 3rd Edition
  * Fixed "#46721: $config->exists() does not pay attention to -nocase => 1"
  - https://rt.cpan.org/Ticket/Display.html?id=46721
  * Fixed the POD for SetParameterEOT:
  - https://rt.cpan.org/Ticket/Display.html?id=28375
  * Added t/pod.t and t/pod-coverage.t and fixed the problems they pointed:
  - Removed some trailing pod.
  - http://rt.cpan.org/Ticket/Display.html?id=46549
  - Documented the ->OutputConfig() method.
* Mon May 18 2009 anicka@suse.cz
- update to 2.49
  * Fixed bug https://rt.cpan.org/Public/Bug/Display.html?id=45209
  * Makefile.PL lacked the empty "PL_FILES" directive.
  * Fixed bug https://rt.cpan.org/Ticket/Display.html?id=45588
  * Failure to read ini file contents from a scalar
  (via "IO::Scalar").
  * added t/23scalar-ref.t
* Tue Apr 14 2009 anicka@suse.cz
- update to 2.48
  * bugfixes, documentation fixes
* Thu Jan 22 2009 anicka@suse.cz
- update to 2.47
  * Moved the eval'ed debugging code (_assert_invariants) to
  its own module
  * Placed IniFiles.pm under lib/Config/IniFiles.pm.
  * Added a Build.PL file for the distribution.
  * Made the README contain the useful information and nothing else
  * bugfixes, test fixes
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jul 11 2005 schubi@suse.de
- update to 2.39
* Tue Oct 21 2003 lmuelle@suse.de
- add norootforbuild to the spec file
* Fri Aug 22 2003 mjancar@suse.cz
- require the perl version we build with
* Thu Aug 14 2003 lmuelle@suse.de
- update to version 2.38
* Fri Jun 13 2003 lmuelle@suse.de
- use perl macros in file list
* Fri Jun 13 2003 lmuelle@suse.de
- add missing directories
* Mon May 19 2003 lmuelle@suse.de
- remove perllocal.pod after install
* Mon May  5 2003 lmuelle@suse.de
- update to 2.37
- remove superfluous document directory, #26659
* Thu Aug  8 2002 mls@suse.de
- use macro in filelist
* Tue Jul  9 2002 ray@suse.de
- update to 2.27
* Tue Jul  2 2002 mls@suse.de
- remove race in .packlist generation
* Mon Feb 25 2002 choeger@suse.de
- perlmodule and some README files had been executable
* Mon May 21 2001 choeger@suse.de
- update to version 2.19
* Wed Nov 15 2000 choeger@suse.de
- long package name
- buildroot
* Wed Aug 16 2000 choeger@suse.de
- first package, v0.09
